/*
 * Definiowanie Menu Głównego WindowMakera
 * Fonty w standardzie ISO8859-2
 *
 * Składnia jest następująca:
 *
 * <Tytuł> [SHORTCUT <Skrót>] <Komenda> <Parametry>
 *
 * <Tytuł> Tytuł może być dowolnym ciągiem znaków. Jeśli będą w nim występować
 *         spacje umieść go w cudzysłowie np. "Tytuł ze spacją"
 * 
 * SHORTCUT Definiowanie skrótu.
 * <Skrót> Nazwa rodzaju skrótu umieszczonego w pliku
 *         $HOME/GNUstep/Defaults/WindowMaker, tak jak RootMenuKey 
 *         lub MiniaturizeKey.
 *
 * Skróty mogą występować w sekcji MENU lub OPEN_MENU .
 * 
 * <Komenda> jedna z dostępnych komend: 
 *	MENU - rozpoczęcie definicji (pod)menu 
 *	END  - zakończenie definicji (pod)menu 
 *	OPEN_MENU - generowanie podmenu na podstawie podanego katalogu,
 *              umieszczając w nim pliki wykonywalne i podkatalogi.
 *	WORKSPACE_MENU - Dodanie podmenu zawierającego aktywne pulpity. Tylko
 *		             jedno workspace_menu jest potrzebne. 		
 *	EXEC <program> - wykonanie jakiegokolwiek programu
 *	EXIT - wyjście z menadżera okien
 *	RESTART [<window manager>] - restart WindowMakera albo start innego
 *			                     manadżera okien
 *	REFRESH - odświerzenie ekranu
 *	ARRANGE_ICONS - uporządkowanie ikon na pulpicie
 *	SHUTDOWN - zabicie wszystkich procesów (i wyjście z X window)
 *	SHOW_ALL - pokazanie wszystkich ukrytych programów
 *  HIDE_OTHERS - schowanie aktywnych okien pulpitu, oprócz aktywnego
 *  SAVE_SESSION - zapamietanie aktualnego stanu desktpou, z wszystkimi
 *                 uruchomionymi programami, i z wszystkimi ich stanami
 *                 geometrycznymi, pozycji na ekranie, umieszczone na
 *                 odpowiednim pulpicie, ukryte lub uaktywnione.
 *                 Wszystkie te ustawiemia bedą aktywne, dopóki nie
 *                 zostaną użyte komendy SAVE_SESSION i CLEAR_SESSION.
 *                 Jeżeli SaveSessionOnExit = Yes; w pliku konfiguracyjnym
 *                 WindowMakera, wtedy zapamiętywanie wszystkich ustawień
 *                 jest dokonywanie po każdym wyjściu, niezależnie od
 *                 komend SAVE_SESSION czy CLEAR_SESSION .
 *  CLEAR_SESSION - Czyszczenie poprzednio zapamiętanych sesji. Nie ponosi to
 *                  żadnych zmian w pliku SaveSessionOnExit .
 *  INFO - Wyświetlenie informacji o WindowMakerze
 *
 * <Parametry> zależne od uruchamianego programu.
 *
 * ** Opcje w lini komend EXEC:
 * %s - znak jest zastępowany przez text znajdujący się w 'schowku'
 * %a(tytuł[,komunikat]) - otwiera dodatkowe okno o tytule 'tytuł', komunikacie
 *                         'komunikat' i czeka na podanie parametrów, które 
 *                         zostaną wstawione zamiast %a. 
 * %w - znak jest zastępowany przez XID aktywnego okna
 * %W - znak jest zastępowany przez numer aktywnego pulpitu
 * 
 * Aby używać specjalnych znaków ( takich jak % czy " ) należy poprzedzić je znakiem \
 * np. :xterm -T "\"Witaj Świecie\""
 *
 * Można używać znaków specjalnych, takich jak \n
 *
 * Sekcja MENU musi być zakończona sekcją END, pod tą samą nazwą.
 *
 * Przykład:
 *
 * "Test" MENU
 *  "XTerm" EXEC xterm
 *      // stworzenie podmenu z plikami w podkatalogu /usr/openwin/bin
 *  "XView apps" OPEN_MENU "/usr/openwin/bin"
 *      // umieszcza w jednym podmenu pliki z różnych podkatalogów
 *  "X11 apps" OPEN_MENU /usr/X11/bin $HOME/bin/X11
 *      // ustawienie tła
 *  "Background" OPEN_MENU -noext $HOME/images /usr/share/images WITH wmsetbg -u *      // wstawienie menu z pliku style.menu
 *      // wstawienie menu z pliku style.menu
 *  "Style" OPEN_MENU style.menu
 * "Test" END
 *
 * Jeżeli zamiast polskich fontów są jakieś krzaczki należy wyedetować pliki
 * $HOME/GNUstep/Defaults/WMGLOBAL i $HOME/GNUstep/Defaults/WindowMaker,  
 * lub wejść w menu Konfiguracja.
 * Aby uzyskać polskie znaki należy uzupełnić definicje fontów.
 * np. zamienić
 *
 * SystemFont = "-*-helvetica-medium-r-normal-*-%d-100-*-*-*-*-*-*";
 *
 * na
 *
 * SystemFont = "-*-helvetica-medium-r-normal-*-%d-100-*-*-*-*-iso8859-2";
 *
 * i wszędzie tam gdzie występuje podobna definicja.
 */
                  

#include "wmmacros"

"WindowMaker" MENU
	"Informacja" MENU
		"Informacja o WindowMakerze..."      INFO_PANEL
		"Informacja o licencji..." LEGAL_PANEL
		"Konsola systemu"        EXEC xconsole
		"Obciążenie systemu"     SHEXEC xosview || xload
		"Lista procesów"         EXEC xterm -T "Lista procesów" -e top
		"Przeglądarka manuali"   EXEC xman
	"Informacja" END
	
        "XTerm" EXEC xterm
        "ATerm"  EXEC aterm
	"Pulpity" WORKSPACE_MENU
	
	"Aplikacje" OPEN_MENU | wmconfig --output wmaker --rootmenu Applications 2>/dev/null

	"Zaznaczenie" MENU
		"Kopiuj"                  SHEXEC echo '%s' | wxcopy
		"Poczta do ..."          EXEC xterm -name mail -T "Pine" -e pine %s
		"Serfuj do ..."          EXEC netscape %s
		"Szukaj w manualach ..."     SHEXEC MANUAL_SEARCH(%s)
	"Zaznaczenie" END

	"Ekran" MENU
		"Ukryj pozostałe"         HIDE_OTHERS
		"Pokaż wszystko"          SHOW_ALL
		"Uporządkuj ikony"        ARRANGE_ICONS
		"Odśwież"                 REFRESH
		"Zablokuj"                EXEC xlock -allowroot -usefirst
		"Zachowaj sesję"          SAVE_SESSION
		"Wyczyść zachowaną sesję" CLEAR_SESSION
	"Ekran" END

	"Wygląd" MENU
		"Tematy"          OPEN_MENU -noext THEMES_DIR $HOME/GNUstep/Library/WindowMaker/Themes WITH setstyle
		"Style"           OPEN_MENU -noext STYLES_DIR $HOME/GNUstep/Library/WindowMaker/Styles WITH setstyle
		"Ustawienia ikon" OPEN_MENU -noext ICON_SETS_DIR $HOME/GNUstep/Library/WindowMaker/IconSets WITH seticons
		"Tło" MENU
			"Jednolite" MENU
               	"Czarny"            WS_BACK '(solid, black)'
               	"Niebieski"         WS_BACK '(solid, "#505075")'
				"Indigo"            WS_BACK '(solid, "#243e6c")'
				"Głęboko Niebieski" WS_BACK '(solid, "#224477")'
               	"Fioletowy"         WS_BACK '(solid, "#554466")'
               	"Pszeniczny"        WS_BACK '(solid, "wheat4")'
               	"Ciemno Szary"      WS_BACK '(solid, "#333340")'
               	"Winny"             WS_BACK '(solid, "#400020")'
			"Jednolite" END
			"Cieniowane" MENU
				"Zachód Słońca"         WS_BACK '(mvgradient, deepskyblue4, black, deepskyblue4, tomato4)'
				"Niebo"                 WS_BACK '(vgradient, blue4, white)'
    			"Cieniowany Niebieski"  WS_BACK '(vgradient, "#7080a5", "#101020")'
				"Cieniowane Indigo"     WS_BACK '(vgradient, "#746ebc", "#242e4c")'
			   	"Cieniowany Fioletowy"  WS_BACK '(vgradient, "#654c66", "#151426")'
    			"Cieniowany Pszeniczny" WS_BACK '(vgradient, "#a09060", "#302010")'
    			"Cieniowany Szary"      WS_BACK '(vgradient, "#636380", "#131318")'
    			"Cieniowany Winnny"     WS_BACK '(vgradient, "#600040", "#180010")'
			"Cieniowane" END
			"Obrazki" OPEN_MENU -noext BACKGROUNDS_DIR $HOME/GNUstep/Library/WindowMaker/Backgrounds WITH wmsetbg -u -t
		"Tło" END
		"Zaoamiętanie Tematu"        EXEC getstyle -t $HOME/GNUstep/Library/WindowMaker/Themes/"%a(Nazwa tematu,Wpisz nazwe pliku:)"
		"Zapamiętanie Ustawień Ikon" EXEC geticonset $HOME/GNUstep/Library/WindowMaker/IconSets/"%a(Ustawienia ikon,wpisz nazwe pliku:)"
	"Wygląd" END

	"Wyjście" MENU
		"Przeładowanie"    RESTART
		"Start BlackBox"   RESTART blackbox
		"Start kwm"        RESTART kwm
		"Start IceWM"      RESTART icewm
		"Wyjście..."       EXIT
		"Zabicie sesji..." SHUTDOWN
	"Wyjście" END
"WindowMaker" END
